import {render, screen, cleanup, waitFor} from '@testing-library/react'
import '@testing-library/jest-dom'
import Amounts from "../pages/amount";
import fetch from 'node-fetch';

const items = [
    {date: '2018-01-01', value: 50},
    {date: '2018-02-01', value: 40},
    {date: '2018-03-01', value: 45},
    {date: '2018-04-01', value: 35},
    {date: '2018-05-01', value: 55},
    {date: '2018-06-01', value: 30},
    {date: '2018-07-01', value: 120},
    {date: '2018-08-01', value: 155},
    {date: '2018-09-01', value: 130},
    {date: '2018-10-01', value: 200},
    {date: '2018-11-01', value: 250},
    {date: '2018-12-01', value: 20},
    {date: '2019-01-01', value: 70},
]

jest.mock('node-fetch');

describe('Tests sur le graphe du nombre de ventes', () => {
    describe('Test sans données', () => {
        beforeEach(() => {
            fetch.mockReturnValue(Promise.resolve({
                json: () => Promise.resolve({ data: [] })
            }));
            render(<Amounts />)
        })
        afterEach(() => {
            fetch.mockClear();
            cleanup();
        })
        test('Page de base', () => {
            const spinner = screen.getByTestId("spinner")
            expect(spinner).toBeInTheDocument();
        })
    })
    describe('Test avec des données allant de 2018 à 2019', () => {
        beforeEach(() => {
            fetch.mockReturnValue(Promise.resolve({
                json: () => Promise.resolve({ data: {amounts: items} })
            }));
            render(<Amounts />)
        })
        afterEach(() => {
            fetch.mockClear();
            cleanup();
        })
        test('Page de base', async () => {
            await waitFor(() => {
                for(let item of items){
                    let itemG = screen.getByTestId(`data:${item.date}T00:00:00.000Z`);
                    expect(itemG).toBeInTheDocument();
                }
            })
        })
    })
})